@@ -23,18 +23,27 @@
 #ifndef _GRAIL_IMPL_H
 #define _GRAIL_IMPL_H
 
-#include <grail-touch.h>
+#define MTDEV_NO_LEGACY_API
+#define GRAIL_NO_LEGACY_API
+
+#include <grail.h>
+#include <utouch/frame-mtdev.h>
 #include "evbuf.h"
+#include "grailbuf.h"
+
+#define DIM_TOUCH		32
+#define DIM_TOUCH_BYTES		((DIM_TOUCH + 7) >> 3)
 
 struct grail_impl {
-	struct touch_dev dev;
+	struct evemu_device *evemu;
+	struct mtdev *mtdev;
+	utouch_frame_handle fh;
+	const struct utouch_frame *frame;
 	struct evbuf evbuf;
+	struct grailbuf gbuf;
 	int filter_abs;
-	int pointer_status;
-	int pointer_x, pointer_y;
-	int report_status;
-	int report_x, report_y;
-	struct timeval report_time;
+	int ongoing;
+	int gesture;
 };
 
 #endif
