@@ -26,7 +26,6 @@
 #include "grail-gestures.h"
 
 struct gesture_recognizer {
-	struct touch_frame frame;
 	struct move_model move;
 	struct combo_model drag;
 	struct combo_model pinch;
@@ -38,7 +37,7 @@ struct gesture_recognizer {
 };
 
 int gru_init(struct grail *ge);
-void gru_recognize(struct grail *ge, const struct touch_frame *frame);
+void gru_recognize(struct grail *ge, const struct utouch_frame *frame);
 void gru_destroy(struct grail *ge);
 
 #endif
